<?php
if (!defined('ABSPATH')) exit('No direct script access allowed');

 /**
 * CodeNegar Carousel Slider functions
 *
 * Carousel Slider Helper Class
 *
 * @package    	WordPress Carousel Slider
 * @author      Farhad Ahmadi <ahm.farhad@gmail.com>
 * @license     http://codecanyon.net/licenses
 * @link		http://codenegar.com/roundabout-carousel-slider/
 * @version    	1.2
 */
 
class CodeNegar_rcs_helper{
	
	function __construct(){
		
	}
	
	/**
	* Converts string to int and makes sure string parameters are safe
	* @param string/int/array $input, user input value
	* @param boolean $is_int, force convert to int 
	* @return string/int safe parameter
	*/
	
	public function prepare_parameter($input, $is_int=false){
	
		if(is_array($input)){
			foreach($input as $key=>$value){
				if($is_int){
					$input[$key] = intval($value);
				}else{
					$input[$key] = trim(stripslashes(strip_tags($value)));
				}
			}
		}else{
			if($is_int){
				$input = intval($input);
			}else{
				$input = trim(stripslashes(strip_tags($input)));
			}
		}
		return $input;
	}
	
	/**
	* Return limit length of a Wordpress post
	* @param int $limit, number of maximum characters to return
	* @return string limited character of current wordpress post
	*/
	
	public function limit_str($str, $limit=100) {
        $str = trim(strip_tags($str));
		$str = strip_shortcodes($str);
		$excerpt = mb_substr($str,0,$limit);
		if (strlen($excerpt)<strlen($str)) {
			$excerpt .= '...';
		}
		return $excerpt;
	}
	
	
	/**
	* Converts stdClass to array
	* @return array of input
	*/
	
	public function object_to_array($input){
		if (is_object($input)) {
			$input = get_object_vars($input);
		}
		if (is_array($input)) {
			return array_map(array(&$this, 'object_to_array'), $input);
		}
		else {
			return $input;
		}
	}
	
	/**
	* Converts array to stdClass
	* @return stdClass of input
	*/
	
	public function array_to_object($input){
		if (is_array($input)) {
			return (object) array_map(array(&$this, 'array_to_object'), $input);
		}
		else {
			return $input;
		}
	}
	
	/**
	* Carousel Slider default options
	* @return array of default options
	*/
	
	public function default_options(){
		$prefix = '_cnrcs_';
		$defaults = array(
			$prefix . 'number_of_slides' => 0,
			$prefix . 'autoplay' => '',
			$prefix . 'autoplaypauseonhover' => '',
			$prefix . 'autoplayduration' => 1000,
			$prefix . 'autoplayinitialdelay' => 0,
			$prefix . 'enabledrag' => '',
			$prefix . 'dropduration' => 400,
			$prefix . 'dropeasing' => 'swing',
			$prefix . 'dropanimateto' => 'nearest',
			$prefix . 'dragaxis' => 'x',
			$prefix . 'dragfactor' => 4,
			$prefix . 'slider_with' => '180',
			$prefix . 'slider_height' => '160',
			$prefix . 'slide_with' => '100',
			$prefix . 'slide_height' => '150',
			$prefix . 'minz' => 100,
			$prefix . 'maxz' => 280,
			$prefix . 'minopacity' => '0.4',
			$prefix . 'maxopacity' => '1.0',
			$prefix . 'minscale' => '0.4',
			$prefix . 'maxscale' => '1.0',
			$prefix . 'slide_padding' => '0',
			$prefix . 'duration' => 400,
			$prefix . 'shape' => 'lazySusan',
			$prefix . 'bearing' => 0.0,
			$prefix . 'focusbearing' => 0.0,
			$prefix . 'tilt' => 0.0,
			$prefix . 'html_contents' => '',
			$prefix . 'image' => '',
			$prefix . 'data_src' => 'html',
			$prefix . 'responsive' => 'on',
			$prefix . 'custom_slider_class' => '',
			$prefix . 'custom_slide_class' => '',
			$prefix . 'custom_advanced_css' => '',
			$prefix . 'easing' => 'swing',
			$prefix . 'enable_subtitle' => '',
			$prefix . 'subtitle_contents' => '',
			$prefix . 'subtitle_top_space' => '50',
			$prefix . 'subtitle_left_space' => '50',
			$prefix . 'subtitle_show_effect' => 'fadeIn',
			$prefix . 'subtitle_hide_effect' => 'hide',
			$prefix . 'enable_background' => '',
			$prefix . 'background_type' => 'color',
			$prefix . 'background_image_repeat' => 'no-repeat',
			$prefix . 'background_color' => '#ffffff',
			$prefix . 'slides_border_style' => 'none',
			$prefix . 'slides_border_color' => '#000000',
			$prefix . 'slides_border_width' => 1,
			$prefix . 'background_image' => '',
			$prefix . 'custom_slide_css' => '',
			$prefix . 'background_image_position' => 'center center',
			$prefix . 'enable_navigation' => '',
			$prefix . 'navigation_contents' => '',
			$prefix . 'navigation_height' => '20',
			$prefix . 'navigation_width' => '20',
			$prefix . 'navigation_left_space' => '50',
			$prefix . 'navigation_top_space' => '50',
			$prefix . 'navigation_seperator_space' => '2',
			$prefix . 'navigation_radious' => '10',
			$prefix . 'navigation_line_height' => '10',
			$prefix . 'navigation_background_color' => '#000000',
			$prefix . 'navigation_background_hover_color' => '#000000',
			$prefix . 'navigation_background_active_color' => '#000000',
			$prefix . 'navigation_border_color' => '#000000',
			$prefix . 'navigation_border_style' => 'none',
			$prefix . 'navigation_border_width' => '2',
		);
		return $defaults;
	}
	
	public function clean_meta($post_custom){
		$return = array();
		foreach($post_custom as $key=>$val){
			$return[$key] = $val[0];
		}
		return $return;
	}

	public function post_update_messages( $messages ) {
	  global $post, $post_ID, $codeNegar_rcs;

	  $messages['roundabout_slider'] = array(
		0 => '', // Unused. Messages start at index 1.
		1 => sprintf( __('Slider saved. Shortcode: %s', $codeNegar_rcs->text_domain), '[roundabout_slider id="' . $post_ID . '"]'),
		2 => __('Custom field updated.', $codeNegar_rcs->text_domain),
		3 => __('Custom field deleted.', $codeNegar_rcs->text_domain),
		4 => __('Slider updated.', $codeNegar_rcs->text_domain),
		5 => isset($_GET['revision']) ? sprintf( __('Slider restored to revision from %s', $codeNegar_rcs->text_domain), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Slider saved. Shortcode: %s', $codeNegar_rcs->text_domain), '[roundabout_slider id="' . $post_ID . '"]'),
		7 => __('Slider saved.', $codeNegar_rcs->text_domain),
		8 => __('Slider submitted.', $codeNegar_rcs->text_domain),
		9 => sprintf( __('Slider scheduled for: <strong>%1$s</strong>.', $codeNegar_rcs->text_domain), date_i18n( __( 'M j, Y @ G:i', $codeNegar_rcs->text_domain), strtotime( $post->post_date ) , esc_url( get_permalink($post_ID) ) )),
		10 => __('Slider draft updated.', $codeNegar_rcs->text_domain)
	  );
	  return $messages;
	}
	
	public function remove_row_actions( $actions ){
		if( get_post_type() === 'roundabout_slider' ){
			unset( $actions['view'] );
			unset( $actions['inline hide-if-no-js'] );
		}
		return $actions;
	}
	
	public function save_meta_box_order(){
		$order = isset( $_POST['order'] ) ? (array) $_POST['order'] : false;
		
		if ( $order ){
			$post_id = 0;
			if(isset($_POST['order']['normal'])){
				$boxes = explode(",", $_POST['order']['normal']);
				
				// if this is not roundabout mataboxes return
				if(strpos($boxes[0], "roundabout_")===false) return;
				$count = count($boxes);
				for($i=0; $i<$count; $i++){
					// if it's an options box skip
					if(strpos($boxes[$i], "_slide_")===false) continue;
					
					// it's a slide box get post id
					$parts = explode("_", $boxes[$i]);
					$post_id = intval($parts[2]);
					// post id is found break the loop
					break;
				}
				
				if($post_id){
					update_post_meta($post_id, "_roundabout_post_order", $order);
				}
			}
		}
		return;
	}
	
	public function set_post_order_as_user_order($post_id){
		if(!$post_id) return;
		$page = 'roundabout_slider';
		$order =  get_post_meta($post_id, "_roundabout_post_order", true);
		if (!$user = wp_get_current_user()) return;
		update_user_option($user->ID, "meta-box-order_$page", $order);
	}
	
	public function rgb2hex($rgb) {
	   $hex = "#";
	   $hex .= str_pad(dechex($rgb[0]), 2, "0", STR_PAD_LEFT);
	   $hex .= str_pad(dechex($rgb[1]), 2, "0", STR_PAD_LEFT);
	   $hex .= str_pad(dechex($rgb[2]), 2, "0", STR_PAD_LEFT);
	   return $hex;
	}
}
?>