<?php
if (!defined('ABSPATH')) exit('No direct script access allowed');

 /**
 * CodeNegar Roundabout Carousel Slider functions
 *
 * Carousel Slider Metabox options
 *
 * @package    	WordPress Carousel Slider
 * @author      Farhad Ahmadi <ahm.farhad@gmail.com>
 * @license     http://codecanyon.net/licenses
 * @link		http://codenegar.com/roundabout-carousel-slider/
 * @version    	1.2
 */

add_filter( 'cmb_meta_boxes', 'codeNegar_rrt_metaboxes' );

/**
 * Define the metabox and field configurations.
 * @param  array $meta_boxes
 * @return array
 */
 
function codeNegar_rrt_metaboxes( array $meta_boxes ) {
	// Start with an underscore to hide fields from custom fields list
	$prefix = '_cnrcs_'; // CodeNegar Roundabout Carousel Slider
	global $codeNegar_rcs;
	$defaults = $codeNegar_rcs->helper->default_options();
	$meta_boxes[] = array(
		'id'         => 'roundabout_slider_drag_drop_options',
		'title'      => __('Options - Drag & Drop', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => __('Enable Drag', $codeNegar_rcs->text_domain),
				'desc' => __('Allows users to rotate Roundabout by clicking and dragging.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'enabledrag'],
				'id'   => $prefix . 'enabledrag',
				'type' => 'checkbox'
			),
			array(
				'name'    => __('Drag Axis', $codeNegar_rcs->text_domain),
				'desc'    => 'The axis along which drag events are measured.',
				'std' => $defaults[$prefix . 'dragaxis'],
				'id'      => $prefix . 'dragaxis',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('Horizontal', $codeNegar_rcs->text_domain), 'value' => 'x' ),
					array( 'name' => __('Vertical', $codeNegar_rcs->text_domain), 'value' => 'y' )
				),
			),
			array(
				'name' => __('Drag Factor', $codeNegar_rcs->text_domain),
				'desc' => __('Alters the rate at which dragging moves the Roundabout\'s moving elements. Higher numbers will cause the moving elements to move less.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'dragfactor'],
				'id'   => $prefix . 'dragfactor',
				'type' => 'text_small',
			),
			array(
				'name'    => __('Drop Slides To', $codeNegar_rcs->text_domain),
				'desc'    => 'Select which slide should be focused when Roundabout is dropped.',
				'std' => $defaults[$prefix . 'dropanimateto'],
				'id'      => $prefix . 'dropanimateto',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('Next', $codeNegar_rcs->text_domain), 'value' => 'next' ),
					array( 'name' => __('previous', $codeNegar_rcs->text_domain), 'value' => 'previous' ),
					array( 'name' => __('Nearest', $codeNegar_rcs->text_domain), 'value' => 'nearest' )
				),
			),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_slider_autoplay_options',
		'title'      => __('Options - Auto Play', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => __('Auto Play', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout will automatically advance the moving elements to the next child at a regular interval.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'autoplay'],
				'id'   => $prefix . 'autoplay',
				'type' => 'checkbox'
			),
			array(
				'name' => __('Auto Pause On Hover', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout will pause autoplay when the user moves the cursor over the Roundabout container.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'autoplaypauseonhover'],
				'id'   => $prefix . 'autoplaypauseonhover',
				'type' => 'checkbox'
			),
			array(
				'name' => __('Auto Play Duration (ms)', $codeNegar_rcs->text_domain),
				'desc' => __('The length of time (in milliseconds) between animation triggers when a Roundabout\'s autoplay is playing.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'autoplayduration'],
				'id'   => $prefix . 'autoplayduration',
				'type' => 'text_small',
			),
			array(
				'name' => __('Auto play Delay (ms)', $codeNegar_rcs->text_domain),
				'desc' => __('The length of time (in milliseconds) to delay the start of Roundabout\'s configured autoplay option. This only works with setting autoplay to true, and only on the first start of autoplay.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'autoplayinitialdelay'],
				'id'   => $prefix . 'autoplayinitialdelay',
				'type' => 'text_small',
			),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_slider_shape_options',
		'title'      => __('Options - Shape', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name'    => __('Moving Path', $codeNegar_rcs->text_domain),
				'desc'    => 'The shape or path that moving elements follow.',
				'std' => $defaults[$prefix . 'shape'],
				'id'      => $prefix . 'shape',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('The Lazy Susan', $codeNegar_rcs->text_domain), 'value' => 'lazySusan' ),
					array( 'name' => __('The Juggler', $codeNegar_rcs->text_domain), 'value' => 'theJuggler' ),
					array( 'name' => __('The Figure 8', $codeNegar_rcs->text_domain), 'value' => 'figure8' ),
					array( 'name' => __('The Water Wheel', $codeNegar_rcs->text_domain), 'value' => 'waterWheel' ),
					array( 'name' => __('The Square', $codeNegar_rcs->text_domain), 'value' => 'square' ),
					array( 'name' => __('The Conveyor Belt (Left)', $codeNegar_rcs->text_domain), 'value' => 'conveyorBeltLeft' ),
					array( 'name' => __('The Conveyor Belt (Right)', $codeNegar_rcs->text_domain), 'value' => 'conveyorBeltRight' ),
					array( 'name' => __('The Goodbye Cruel World', $codeNegar_rcs->text_domain), 'value' => 'goodbyeCruelWorld' ),
					array( 'name' => __('The Diagonal Ring (Left)', $codeNegar_rcs->text_domain), 'value' => 'diagonalRingLeft' ),
					array( 'name' => __('The Diagonal Ring (Right)', $codeNegar_rcs->text_domain), 'value' => 'diagonalRingRight' ),
					array( 'name' => __('The Roller Coaster', $codeNegar_rcs->text_domain), 'value' => 'rollerCoaster' ),
					array( 'name' => __('The Tear Drop', $codeNegar_rcs->text_domain), 'value' => 'tearDrop' ),
					array( 'name' => __('The Ticking Clock', $codeNegar_rcs->text_domain), 'value' => 'tickingClock' ),
					array( 'name' => __('The Flurry', $codeNegar_rcs->text_domain), 'value' => 'flurry' ),
					array( 'name' => __('The Now Slide', $codeNegar_rcs->text_domain), 'value' => 'nowSlide' ),
					array( 'name' => __('The Rising Essence', $codeNegar_rcs->text_domain), 'value' => 'risingEssence' ),
				),
			),
			
			array(
				'name' => __('Bearing', $codeNegar_rcs->text_domain),
				'desc' => __('The starting direction in which Roundabout should face relative to focus point.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'bearing'],
				'id'   => $prefix . 'bearing',
				'type' => 'text_small',
			),
			array(
				'name' => __('Focus Point', $codeNegar_rcs->text_domain),
				'desc' => __('The bearing that Roundabout will use as the focus point. All animations that move Roundabout between children will animate the given child element to this bearing.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'focusbearing'],
				'id'   => $prefix . 'focusbearing',
				'type' => 'text_small',
			),
			array(
				'name' => __('Moving Variation (tilt)', $codeNegar_rcs->text_domain),
				'desc' => __('Slightly alters the shape or path of moving elements.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'tilt'],
				'id'   => $prefix . 'tilt',
				'type' => 'text_small',
			),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_slider_size_options',
		'title'      => __('Options - Size', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => __('Slider Width (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout holder width.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'slider_with'],
				'id'   => $prefix . 'slider_with',
				'type' => 'text_small',
			),
			array(
				'name' => __('Slider Height (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout holder height.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'slider_height'],
				'id'   => $prefix . 'slider_height',
				'type' => 'text_small',
			),
			array(
				'name' => __('Slide Width (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout moveable item width.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'slide_with'],
				'id'   => $prefix . 'slide_with',
				'type' => 'text_small',
			),
			array(
				'name' => __('Slide Height (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout moveable item height.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'slide_height'],
				'id'   => $prefix . 'slide_height',
				'type' => 'text_small',
			),
			array(
				'name' => __('Min Scale', $codeNegar_rcs->text_domain),
				'desc' => __('The lowest size (relative to its starting size) that will be assigned to a moving element.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'minscale'],
				'id'   => $prefix . 'minscale',
				'type' => 'select',
				'options' => array(
					array( 'name' => '0.1', 'value' => '0.1' ),
					array( 'name' => '0.2', 'value' => '0.2' ),
					array( 'name' => '0.3', 'value' => '0.3' ),
					array( 'name' => '0.4', 'value' => '0.4' ),
					array( 'name' => '0.5', 'value' => '0.5' ),
					array( 'name' => '0.6', 'value' => '0.6' ),
					array( 'name' => '0.7', 'value' => '0.7' ),
					array( 'name' => '0.8', 'value' => '0.8' ),
					array( 'name' => '0.9', 'value' => '0.9' ),
					array( 'name' => '1.0', 'value' => '1.0' )
				)
			),
			array(
				'name' => __('Max Scale', $codeNegar_rcs->text_domain),
				'desc' => __('The greatest size (relative to its starting size) that will be assigned to a moving element.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'maxscale'],
				'id'   => $prefix . 'maxscale',
				'type' => 'select',
				'options' => array(
					array( 'name' => '0.1', 'value' => '0.1' ),
					array( 'name' => '0.2', 'value' => '0.2' ),
					array( 'name' => '0.3', 'value' => '0.3' ),
					array( 'name' => '0.4', 'value' => '0.4' ),
					array( 'name' => '0.5', 'value' => '0.5' ),
					array( 'name' => '0.6', 'value' => '0.6' ),
					array( 'name' => '0.7', 'value' => '0.7' ),
					array( 'name' => '0.8', 'value' => '0.8' ),
					array( 'name' => '0.9', 'value' => '0.9' ),
					array( 'name' => '1.0', 'value' => '1.0' )
				)
			),
			array(
				'name' => __('Padding (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Add some space around each slide.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'slide_padding'],
				'id'   => $prefix . 'slide_padding',
				'type' => 'text_small',
			),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_subtitle_options',
		'title'      => __('Options - Subtitle', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => __('Enable Subtitle', $codeNegar_rcs->text_domain),
				'desc' => __('Shows a description for each slide.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'enable_subtitle'],
				'id'   => $prefix . 'enable_subtitle',
				'type' => 'checkbox'
			),
			array(
				'name' => __('Top Space (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout subtitle top space.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'subtitle_top_space'],
				'id'   => $prefix . 'subtitle_top_space',
				'type' => 'text_small',
			),
			array(
				'name' => __('Left Space (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout subtitle left space.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'subtitle_left_space'],
				'id'   => $prefix . 'subtitle_left_space',
				'type' => 'text_small',
			),
			array(
				'name' => __('Show Effect', $codeNegar_rcs->text_domain),
				'desc' => __('Effect for displaying subtitle contents.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'subtitle_show_effect'],
				'id'   => $prefix . 'subtitle_show_effect',
				'type' => 'select',
				'options' => array(
					array( 'name' => __('Show', $codeNegar_rcs->text_domain), 'value' => 'show' ),
					array( 'name' => __('Fade In', $codeNegar_rcs->text_domain), 'value' => 'fadeIn' ),
					array( 'name' => __('Slide Down', $codeNegar_rcs->text_domain), 'value' => 'slideDown' ),
				)
			),
			array(
				'name' => __('Hide Effect', $codeNegar_rcs->text_domain),
				'desc' => __('Effect for hiding subtitle contents.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'subtitle_hide_effect'],
				'id'   => $prefix . 'subtitle_hide_effect',
				'type' => 'select',
				'options' => array(
					array( 'name' => __('Hide', $codeNegar_rcs->text_domain), 'value' => 'hide' ),
					array( 'name' => __('Fade Out', $codeNegar_rcs->text_domain), 'value' => 'fadeOut' ),
					array( 'name' => __('Slide Up', $codeNegar_rcs->text_domain), 'value' => 'slideUp' ),
				)
			),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_slider_animation_options',
		'title'      => __('Options - Animation', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => __('Sliding Speed (ms)', $codeNegar_rcs->text_domain),
				'desc' => __('The length of time Roundabout will take to move from one child element being in focus to another.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'duration'],
				'id'   => $prefix . 'duration',
				'type' => 'text_small',
			),
			array(
				'name'    => __('Sliding Easing', $codeNegar_rcs->text_domain),
				'desc'    => 'The easing function to use when animating Roundabout. <br/> Check demo at <a href="http://gsgd.co.uk/sandbox/jquery/easing/">http://gsgd.co.uk/sandbox/jquery/easing/</a>',
				'std' => $defaults[$prefix . 'easing'],
				'id'      => $prefix . 'easing',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('swing', $codeNegar_rcs->text_domain), 'value' => 'swing' ),
					array( 'name' => __('easeInQuad', $codeNegar_rcs->text_domain), 'value' => 'easeInQuad' ),
					array( 'name' => __('easeOutQuad', $codeNegar_rcs->text_domain), 'value' => 'easeOutQuad' ),
					array( 'name' => __('easeInOutQuad', $codeNegar_rcs->text_domain), 'value' => 'easeInOutQuad' ),
					array( 'name' => __('easeInCubic', $codeNegar_rcs->text_domain), 'value' => 'easeInCubic' ),
					array( 'name' => __('easeOutCubic', $codeNegar_rcs->text_domain), 'value' => 'easeOutCubic' ),
					array( 'name' => __('easeInOutCubic', $codeNegar_rcs->text_domain), 'value' => 'easeInOutCubic' ),
					array( 'name' => __('easeInQuart', $codeNegar_rcs->text_domain), 'value' => 'easeInQuart' ),
					array( 'name' => __('easeOutQuart', $codeNegar_rcs->text_domain), 'value' => 'easeOutQuart' ),
					array( 'name' => __('easeInOutQuart', $codeNegar_rcs->text_domain), 'value' => 'easeInOutQuart' ),
					array( 'name' => __('easeInQuint', $codeNegar_rcs->text_domain), 'value' => 'easeInQuint' ),
					array( 'name' => __('easeOutQuint', $codeNegar_rcs->text_domain), 'value' => 'easeOutQuint' ),
					array( 'name' => __('easeInOutQuint', $codeNegar_rcs->text_domain), 'value' => 'easeInOutQuint' ),
					array( 'name' => __('easeInSine', $codeNegar_rcs->text_domain), 'value' => 'easeInSine' ),
					array( 'name' => __('easeOutSine', $codeNegar_rcs->text_domain), 'value' => 'easeOutSine' ),
					array( 'name' => __('easeInOutSine', $codeNegar_rcs->text_domain), 'value' => 'easeInOutSine' ),
					array( 'name' => __('easeInExpo', $codeNegar_rcs->text_domain), 'value' => 'easeInExpo' ),
					array( 'name' => __('easeOutExpo', $codeNegar_rcs->text_domain), 'value' => 'easeOutExpo' ),
					array( 'name' => __('easeInOutExpo', $codeNegar_rcs->text_domain), 'value' => 'easeInOutExpo' ),
					array( 'name' => __('easeInCirc', $codeNegar_rcs->text_domain), 'value' => 'easeInCirc' ),
					array( 'name' => __('easeOutCirc', $codeNegar_rcs->text_domain), 'value' => 'easeOutCirc' ),
					array( 'name' => __('easeInOutCirc', $codeNegar_rcs->text_domain), 'value' => 'easeInOutCirc' ),
					array( 'name' => __('easeInElastic', $codeNegar_rcs->text_domain), 'value' => 'easeInElastic' ),
					array( 'name' => __('easeOutElastic', $codeNegar_rcs->text_domain), 'value' => 'easeOutElastic' ),
					array( 'name' => __('easeInOutElastic', $codeNegar_rcs->text_domain), 'value' => 'easeInOutElastic' ),
					array( 'name' => __('easeInBack', $codeNegar_rcs->text_domain), 'value' => 'easeInBack' ),
					array( 'name' => __('easeOutBack', $codeNegar_rcs->text_domain), 'value' => 'easeOutBack' ),
					array( 'name' => __('easeInOutBack', $codeNegar_rcs->text_domain), 'value' => 'easeInOutBack' ),
					array( 'name' => __('easeInBounce', $codeNegar_rcs->text_domain), 'value' => 'easeInBounce' ),
					array( 'name' => __('easeOutBounce', $codeNegar_rcs->text_domain), 'value' => 'easeOutBounce' ),
					array( 'name' => __('easeInOutBounce', $codeNegar_rcs->text_domain), 'value' => 'easeInOutBounce' )
				),
			),
			array(
				'name' => __('Drop Duration (ms)', $codeNegar_rcs->text_domain),
				'desc' => __('The length of time (in milliseconds) that animation will take to animate Roundabout when the Roundabout is dropped.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'dropduration'],
				'id'   => $prefix . 'dropduration',
				'type' => 'text_small',
			),
			array(
				'name'    => __('Drop Easing', $codeNegar_rcs->text_domain),
				'desc'    => 'jQuery Easing for drop animation. <br/> Check demo at <a href="http://gsgd.co.uk/sandbox/jquery/easing/">http://gsgd.co.uk/sandbox/jquery/easing/</a>',
				'std' => $defaults[$prefix . 'dropeasing'],
				'id'      => $prefix . 'dropeasing',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('jswing', $codeNegar_rcs->text_domain), 'value' => 'jswing' ),
					array( 'name' => __('easeInQuad', $codeNegar_rcs->text_domain), 'value' => 'easeInQuad' ),
					array( 'name' => __('easeOutQuad', $codeNegar_rcs->text_domain), 'value' => 'easeOutQuad' ),
					array( 'name' => __('easeInOutQuad', $codeNegar_rcs->text_domain), 'value' => 'easeInOutQuad' ),
					array( 'name' => __('easeInCubic', $codeNegar_rcs->text_domain), 'value' => 'easeInCubic' ),
					array( 'name' => __('easeOutCubic', $codeNegar_rcs->text_domain), 'value' => 'easeOutCubic' ),
					array( 'name' => __('easeInOutCubic', $codeNegar_rcs->text_domain), 'value' => 'easeInOutCubic' ),
					array( 'name' => __('easeInQuart', $codeNegar_rcs->text_domain), 'value' => 'easeInQuart' ),
					array( 'name' => __('easeOutQuart', $codeNegar_rcs->text_domain), 'value' => 'easeOutQuart' ),
					array( 'name' => __('easeInOutQuart', $codeNegar_rcs->text_domain), 'value' => 'easeInOutQuart' ),
					array( 'name' => __('easeInQuint', $codeNegar_rcs->text_domain), 'value' => 'easeInQuint' ),
					array( 'name' => __('easeOutQuint', $codeNegar_rcs->text_domain), 'value' => 'easeOutQuint' ),
					array( 'name' => __('easeInOutQuint', $codeNegar_rcs->text_domain), 'value' => 'easeInOutQuint' ),
					array( 'name' => __('easeInSine', $codeNegar_rcs->text_domain), 'value' => 'easeInSine' ),
					array( 'name' => __('easeOutSine', $codeNegar_rcs->text_domain), 'value' => 'easeOutSine' ),
					array( 'name' => __('easeInOutSine', $codeNegar_rcs->text_domain), 'value' => 'easeInOutSine' ),
					array( 'name' => __('easeInExpo', $codeNegar_rcs->text_domain), 'value' => 'easeInExpo' ),
					array( 'name' => __('easeOutExpo', $codeNegar_rcs->text_domain), 'value' => 'easeOutExpo' ),
					array( 'name' => __('easeInOutExpo', $codeNegar_rcs->text_domain), 'value' => 'easeInOutExpo' ),
					array( 'name' => __('easeInCirc', $codeNegar_rcs->text_domain), 'value' => 'easeInCirc' ),
					array( 'name' => __('easeOutCirc', $codeNegar_rcs->text_domain), 'value' => 'easeOutCirc' ),
					array( 'name' => __('easeInOutCirc', $codeNegar_rcs->text_domain), 'value' => 'easeInOutCirc' ),
					array( 'name' => __('easeInElastic', $codeNegar_rcs->text_domain), 'value' => 'easeInElastic' ),
					array( 'name' => __('easeOutElastic', $codeNegar_rcs->text_domain), 'value' => 'easeOutElastic' ),
					array( 'name' => __('easeInOutElastic', $codeNegar_rcs->text_domain), 'value' => 'easeInOutElastic' ),
					array( 'name' => __('easeInBack', $codeNegar_rcs->text_domain), 'value' => 'easeInBack' ),
					array( 'name' => __('easeOutBack', $codeNegar_rcs->text_domain), 'value' => 'easeOutBack' ),
					array( 'name' => __('easeInOutBack', $codeNegar_rcs->text_domain), 'value' => 'easeInOutBack' ),
					array( 'name' => __('easeInBounce', $codeNegar_rcs->text_domain), 'value' => 'easeInBounce' ),
					array( 'name' => __('easeOutBounce', $codeNegar_rcs->text_domain), 'value' => 'easeOutBounce' ),
					array( 'name' => __('easeInOutBounce', $codeNegar_rcs->text_domain), 'value' => 'easeInOutBounce' )
				),
			),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_slider_advanced_options',
		'title'      => __('Options - Advanced', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => __('Slider CSS Class', $codeNegar_rcs->text_domain),
				'desc' => __('Add one or more custom CSS Classes for this slider', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'custom_slider_class'],
				'id'   => $prefix . 'custom_slider_class',
				'type' => 'text',
			),
			array(
				'name' => __('Slide CSS Class', $codeNegar_rcs->text_domain),
				'desc' => __('Add one or more custom CSS Classes for every slide of this slider', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'custom_slide_class'],
				'id'   => $prefix . 'custom_slide_class',
				'type' => 'text',
			),
			array(
				'name' => __('Min z-index', $codeNegar_rcs->text_domain),
				'desc' => __('The lowest z-index that will be assigned to a moving element.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'minz'],
				'id'   => $prefix . 'minz',
				'type' => 'text_small',
			),
			array(
				'name' => __('Max z-index', $codeNegar_rcs->text_domain),
				'desc' => __('The greatest z-index that will be assigned to a moving element.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'maxz'],
				'id'   => $prefix . 'maxz',
				'type' => 'text_small',
			),
			array(
				'name' => __('Min Opacity', $codeNegar_rcs->text_domain),
				'desc' => __('The lowest opacity that will be assigned to a moving element.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'minopacity'],
				'id'   => $prefix . 'minopacity',
				'type' => 'select',
				'options' => array(
					array( 'name' => '0.1', 'value' => '0.1' ),
					array( 'name' => '0.2', 'value' => '0.2' ),
					array( 'name' => '0.3', 'value' => '0.3' ),
					array( 'name' => '0.4', 'value' => '0.4' ),
					array( 'name' => '0.5', 'value' => '0.5' ),
					array( 'name' => '0.6', 'value' => '0.6' ),
					array( 'name' => '0.7', 'value' => '0.7' ),
					array( 'name' => '0.8', 'value' => '0.8' ),
					array( 'name' => '0.9', 'value' => '0.9' ),
					array( 'name' => '1.0', 'value' => '1.0' )
				)
			),
			array(
				'name' => __('Max Opacity', $codeNegar_rcs->text_domain),
				'desc' => __('The greatest opacity that will be assigned to a moving element.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'maxopacity'],
				'id'   => $prefix . 'maxopacity',
				'type' => 'select',
				'options' => array(
					array( 'name' => '0.1', 'value' => '0.1' ),
					array( 'name' => '0.2', 'value' => '0.2' ),
					array( 'name' => '0.3', 'value' => '0.3' ),
					array( 'name' => '0.4', 'value' => '0.4' ),
					array( 'name' => '0.5', 'value' => '0.5' ),
					array( 'name' => '0.6', 'value' => '0.6' ),
					array( 'name' => '0.7', 'value' => '0.7' ),
					array( 'name' => '0.8', 'value' => '0.8' ),
					array( 'name' => '0.9', 'value' => '0.9' ),
					array( 'name' => '1.0', 'value' => '1.0' )
				)
			),
			array(
				'name' => __('Custom Styles', $codeNegar_rcs->text_domain),
				'desc' => __('You can enter custom CSS code here.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'custom_advanced_css'],
				'id'   => $prefix . 'custom_advanced_css',
				'type' => 'textarea_small',
			),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_slider_options',
		'title'      => __('Main', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name' => __('Number of Slides', $codeNegar_rcs->text_domain),
				'desc' => __('Enter number of current slider items and press Publish or Update button.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'number_of_slides'],
				'id'   => $prefix . 'number_of_slides',
				'type' => 'number',
			),
			// array(
				// 'name' => __('Responsive', $codeNegar_rcs->text_domain),
				// 'desc' => __('Automatically relayout Roundabout\'s child elements as the holder element changes size.', $codeNegar_rcs->text_domain),
				// 'std' => $defaults[$prefix . 'responsive'],
				// 'id'   => $prefix . 'responsive',
				// 'type' => 'checkbox'
			// ),
		)
	);
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_background_options',
		'title'      => __('Options - Background', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name' => __('Enable Background', $codeNegar_rcs->text_domain),
				'desc' => __('Add color or image background for slides.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'enable_background'],
				'id'   => $prefix . 'enable_background',
				'type' => 'checkbox'
			),
			array(
				'name'    => __('Background Type', $codeNegar_rcs->text_domain),
				'desc'    => 'Select a property for slides background.',
				'std' => $defaults[$prefix . 'background_type'],
				'id'      => $prefix . 'background_type',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('Image', $codeNegar_rcs->text_domain), 'value' => 'image' ),
					array( 'name' => __('Color', $codeNegar_rcs->text_domain), 'value' => 'color' ),
					array( 'name' => __('Color + Image', $codeNegar_rcs->text_domain), 'value' => 'color_image' )
				)
			),
			array(
				'name' => __('Image', $codeNegar_rcs->text_domain),
				'desc' => __('If you have selected image type above, here you should set its image.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'background_image'],
				'id'   => $prefix . 'background_image',
				'type' => 'file'
			),
			array(
				'name'    => __('Image Repeat', $codeNegar_rcs->text_domain),
				'desc'    => 'If you have selected image type above, here you should set its repeat option.',
				'std' => $defaults[$prefix . 'background_image_repeat'],
				'id'      => $prefix . 'background_image_repeat',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('No Repeat', $codeNegar_rcs->text_domain), 'value' => 'no-repeat' ),
					array( 'name' => __('Horizontally', $codeNegar_rcs->text_domain), 'value' => 'repeat-x' ),
					array( 'name' => __('Vertically', $codeNegar_rcs->text_domain), 'value' => 'repeat-y' ),
					array( 'name' => __('Both', $codeNegar_rcs->text_domain), 'value' => 'repeat' ),
				)
			),
			array(
				'name'    => __('Image Position', $codeNegar_rcs->text_domain),
				'desc'    => 'If you have selected no repeat image type above, here you should set its position.',
				'std' => $defaults[$prefix . 'background_image_position'],
				'id'      => $prefix . 'background_image_position',
				'type'    => 'select',
				'options' => array(
					array( 'name' => __('Left Top', $codeNegar_rcs->text_domain), 'value' => 'left top' ),
					array( 'name' => __('Left Center', $codeNegar_rcs->text_domain), 'value' => 'left center' ),
					array( 'name' => __('Left Bottom', $codeNegar_rcs->text_domain), 'value' => 'left bottom' ),
					array( 'name' => __('Right Top', $codeNegar_rcs->text_domain), 'value' => 'right top' ),
					array( 'name' => __('Right Center', $codeNegar_rcs->text_domain), 'value' => 'right center' ),
					array( 'name' => __('Right Bottom', $codeNegar_rcs->text_domain), 'value' => 'right bottom' ),
					array( 'name' => __('Center Top', $codeNegar_rcs->text_domain), 'value' => 'center top' ),
					array( 'name' => __('Center Center', $codeNegar_rcs->text_domain), 'value' => 'center center' ),
					array( 'name' => __('Center Bottom', $codeNegar_rcs->text_domain), 'value' => 'center bottom' )
				)
			),
			array(
				'name' => __('Color', $codeNegar_rcs->text_domain),
				'desc' => __('If you have selected color type above, here you should set the color.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'background_color'],
				'id'   => $prefix . 'background_color',
				'type' => 'colorpicker',
			),
			array(
			'name'    => __('Border Style', $codeNegar_rcs->text_domain),
			'desc'    => 'Select the border style for slides.',
			'std' => $defaults[$prefix . 'slides_border_style'],
			'id'      => $prefix . 'slides_border_style',
			'type'    => 'select',
			'options' => array(
				array( 'name' => __('No Border', $codeNegar_rcs->text_domain), 'value' => 'none' ),
				array( 'name' => __('Hidden', $codeNegar_rcs->text_domain), 'value' => 'hidden' ),
				array( 'name' => __('Dotted', $codeNegar_rcs->text_domain), 'value' => 'dotted' ),
				array( 'name' => __('Dashed', $codeNegar_rcs->text_domain), 'value' => 'dashed' ),
				array( 'name' => __('Solid', $codeNegar_rcs->text_domain), 'value' => 'solid' ),
				array( 'name' => __('Double', $codeNegar_rcs->text_domain), 'value' => 'double' ),
				array( 'name' => __('Groove', $codeNegar_rcs->text_domain), 'value' => 'groove' ),
				array( 'name' => __('Ridge', $codeNegar_rcs->text_domain), 'value' => 'ridge' ),
				array( 'name' => __('Inset', $codeNegar_rcs->text_domain), 'value' => 'inset' ),
				array( 'name' => __('Outset', $codeNegar_rcs->text_domain), 'value' => 'outset' )
				)
			),
			array(
				'name' => __('Border Width (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Border width of slides.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'slides_border_width'],
				'id'   => $prefix . 'slides_border_width',
				'type' => 'text_small',
			),
			array(
				'name' => __('Border Color', $codeNegar_rcs->text_domain),
				'desc' => __('Border color of slides.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'slides_border_color'],
				'id'   => $prefix . 'slides_border_color',
				'type' => 'colorpicker',
			),
			array(
				'name' => __('Custom Style For Slides', $codeNegar_rcs->text_domain),
				'desc' => __('You can enter custom CSS code to apply to slides.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'custom_slide_css'],
				'id'   => $prefix . 'custom_slide_css',
				'type' => 'textarea_small',
			),
		)
	);
	
	
	$post_id = 0;
	$number_of_slides = 0;
	$enable_subtitle = false;
	$enable_navigation = false;
	global $_GET;
	if(isset($_GET['post']) && intval($_GET['post'])>0){
		$post_id = intval($_GET['post']);
		$number_of_slides = (int)(get_post_meta($post_id, $prefix . 'number_of_slides', true));
		$enable_subtitle = ((get_post_meta($post_id, $prefix . 'enable_subtitle', true)) == 'on')? true : false;
		$enable_navigation = ((get_post_meta($post_id, $prefix . 'enable_navigation', true)) == 'on')? true : false;
	}elseif(isset($_POST['post_ID'])){
		$post_id = intval($_POST['post_ID']);
		$number_of_slides = (int)(get_post_meta($post_id, $prefix . 'number_of_slides', true));
		$enable_subtitle = ((get_post_meta($post_id, $prefix . 'enable_subtitle', true)) == 'on')? true : false;
		$enable_navigation = ((get_post_meta($post_id, $prefix . 'enable_navigation', true)) == 'on')? true : false;
	}
	if($post_id){
		$codeNegar_rcs->helper->set_post_order_as_user_order($post_id);
	}

	$count_of_slides = intval(trim($number_of_slides));
	for($i=1; $i<=$count_of_slides; $i++){
	$temp_array = array(
		'id'         => 'roundabout_post_'.$post_id.'_slide_'.$i,
		'title'      => __('Slide Contents #', $codeNegar_rcs->text_domain).$i,
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
			'name'    => __('Data Source', $codeNegar_rcs->text_domain),
			'desc'    => 'Select how Slide data is gotten.',
			'std' => $defaults[$prefix . 'data_src'],
			'id'      => $prefix . 'data_src'.$i,
			'type'    => 'select',
			'options' => array(
				array( 'name' => __('HTML Contents', $codeNegar_rcs->text_domain), 'value' => 'html' ),
				array( 'name' => __('Image', $codeNegar_rcs->text_domain), 'value' => 'image' )
				),
			),
			array(
				'name' => __('HTML Contents', $codeNegar_rcs->text_domain),
				'desc' => '',
				'std' => $defaults[$prefix . 'html_contents'],
				'id'   => $prefix . 'html_contents'.$i,
				'type' => 'wysiwyg'
			),
			array(
				'name' => __('Image', $codeNegar_rcs->text_domain),
				'desc' => __('If you have selected image element type above, here you should set its image.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'image'],
				'id'   => $prefix . 'image'.$i,
				'type' => 'file'
			),
		)
	);
	if($enable_subtitle){
		$temp_array['fields'] [] = array(
				'name' => __('Subtitle', $codeNegar_rcs->text_domain),
				'desc' => '',
				'std' => $defaults[$prefix . 'subtitle_contents'],
				'id'   => $prefix . 'subtitle_contents'.$i,
				'type' => 'wysiwyg'
			);
	}
	if($enable_navigation){
		$temp_array['fields'] [] = array(
				'name' => __('Navigation Contents', $codeNegar_rcs->text_domain),
				'desc' => '',
				'std' => $defaults[$prefix . 'navigation_contents'],
				'id'   => $prefix . 'navigation_contents'.$i,
				'type' => 'wysiwyg'
			);
	}
	$meta_boxes[] = $temp_array;
	} //endfor
	
	
	$meta_boxes[] = array(
		'id'         => 'roundabout_navigation_options',
		'title'      => __('Options - Navigation', $codeNegar_rcs->text_domain),
		'pages'      => array( 'roundabout_slider' ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name' => __('Enable Navigation', $codeNegar_rcs->text_domain),
				'desc' => __('Add custom navigation controls to slider. Press Publish or Update button after changing the state.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'enable_navigation'],
				'id'   => $prefix . 'enable_navigation',
				'type' => 'checkbox'
			),
			array(
				'name' => __('Height (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Height of each navigation control.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_height'],
				'id'   => $prefix . 'navigation_height',
				'type' => 'text_small',
			),
			array(
				'name' => __('Width (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Width of each navigation control.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_width'],
				'id'   => $prefix . 'navigation_width',
				'type' => 'text_small',
			),
			array(
				'name' => __('Top Space (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout navigation top space.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_top_space'],
				'id'   => $prefix . 'navigation_top_space',
				'type' => 'text_small',
			),
			array(
				'name' => __('Left Space (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Roundabout navigation left space.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_left_space'],
				'id'   => $prefix . 'navigation_left_space',
				'type' => 'text_small',
			),
			array(
				'name' => __('Seperator Space (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Space between each navigation control.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_seperator_space'],
				'id'   => $prefix . 'navigation_seperator_space',
				'type' => 'text_small',
			),
			array(
				'name' => __('Line Height (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Line height of each navigation control. This option lets you control navigation text vertical position.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_line_height'],
				'id'   => $prefix . 'navigation_line_height',
				'type' => 'text_small',
			),
			array(
				'name' => __('Background Color', $codeNegar_rcs->text_domain),
				'desc' => __('Background color for navigation controls.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_background_color'],
				'id'   => $prefix . 'navigation_background_color',
				'type' => 'colorpicker',
			),
			array(
				'name' => __('Background Hover Color', $codeNegar_rcs->text_domain),
				'desc' => __('Background color for hovered navigation control.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_background_hover_color'],
				'id'   => $prefix . 'navigation_background_hover_color',
				'type' => 'colorpicker',
			),
			array(
				'name' => __('Background Active Color', $codeNegar_rcs->text_domain),
				'desc' => __('Background color for active navigation control.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_background_active_color'],
				'id'   => $prefix . 'navigation_background_active_color',
				'type' => 'colorpicker',
			),
			array(
				'name' => __('Border Color', $codeNegar_rcs->text_domain),
				'desc' => __('Border Color for navigation controls.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_border_color'],
				'id'   => $prefix . 'navigation_border_color',
				'type' => 'colorpicker',
			),
			array(
				'name' => __('Radious (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Radious of navigation controls.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_radious'],
				'id'   => $prefix . 'navigation_radious',
				'type' => 'text_small',
			),
			array(
			'name'    => __('Border Style', $codeNegar_rcs->text_domain),
			'desc'    => 'Select the style of the navigation controls borders.',
			'std' => $defaults[$prefix . 'navigation_border_style'],
			'id'      => $prefix . 'navigation_border_style',
			'type'    => 'select',
			'options' => array(
				array( 'name' => __('No Border', $codeNegar_rcs->text_domain), 'value' => 'none' ),
				array( 'name' => __('Hidden', $codeNegar_rcs->text_domain), 'value' => 'hidden' ),
				array( 'name' => __('Dotted', $codeNegar_rcs->text_domain), 'value' => 'dotted' ),
				array( 'name' => __('Dashed', $codeNegar_rcs->text_domain), 'value' => 'dashed' ),
				array( 'name' => __('Solid', $codeNegar_rcs->text_domain), 'value' => 'solid' ),
				array( 'name' => __('Double', $codeNegar_rcs->text_domain), 'value' => 'double' ),
				array( 'name' => __('Groove', $codeNegar_rcs->text_domain), 'value' => 'groove' ),
				array( 'name' => __('Ridge', $codeNegar_rcs->text_domain), 'value' => 'ridge' ),
				array( 'name' => __('Inset', $codeNegar_rcs->text_domain), 'value' => 'inset' ),
				array( 'name' => __('Outset', $codeNegar_rcs->text_domain), 'value' => 'outset' )
				)
			),
			array(
				'name' => __('Border Width (px)', $codeNegar_rcs->text_domain),
				'desc' => __('Border Width of the navigation controls.', $codeNegar_rcs->text_domain),
				'std' => $defaults[$prefix . 'navigation_border_width'],
				'id'   => $prefix . 'navigation_border_width',
				'type' => 'text_small',
			),
		)
	);
	
	
	return $meta_boxes;
}

add_action( 'init', 'cn_rcs_cmb_initialize_cmb_meta_boxes', 9999 );

/**
 * Initialize the metabox class.
 */
 
function cn_rcs_cmb_initialize_cmb_meta_boxes() {
	global $codeNegar_rcs;
	if ( !class_exists( 'codenegar_cmb_Meta_Box' ) )
		require_once $codeNegar_rcs->path . 'metabox/init.php';

}