<?php

/*
Plugin Name: Roundabout Carousel Slider
Plugin URI: http://codenegar.com/roundabout-carousel-slider/
Description: Ready-to-go Full Featured WordPress Slider
Author: Farhad Ahmadi
Version: 1.2
Author URI: http://codenegar.com/
*/

class CodeNegar_rcs {

	public $version = '20150624';
	public $commit_version = '27'; // Git repository commit version
	public $file = '';
	public $path;
	public $url;
	public $html; // CodeNegar_rcs_html object
	public $helper; // CodeNegar_rcs_helper object
	public $text_domain = 'codenegar-rcs';
	public $css = ''; // current displaying items and sliders css

	function __construct() {
		$this->url = WP_PLUGIN_URL . "/" . plugin_basename( dirname(__FILE__)) . '/';
		$this->file = __FILE__;
		$this->path = dirname($this->file) . '/';

		// Check if page is loaded via SSL so load assets with SSL
        if(is_ssl()){
            $this->url = preg_replace('|^http://|', 'https://', $this->url);
        }
        
		require_once($this->path . 'functions.php');
		require_once($this->path . 'helper.php');
		require_once($this->path . 'html.php');
		$this->html = new CodeNegar_rcs_html();
		$this->helper = new CodeNegar_rcs_helper();
	}
	
	function initialize(){
		$this->add_post_type();
		add_filter('widget_text', 'do_shortcode');
		add_shortcode('roundabout_slider',  array($this, 'shortcode'));
		add_shortcode('roundabout_slider',  array($this, 'shortcode'));
		require_once($this->path . 'metabox/roundabout.php');
		add_filter('widget_text', 'do_shortcode'); // Enables using shortcode in text widget
	}

	function shortcode($atts){
		extract(
			shortcode_atts(
				array('id' => 0)
				,$atts
			)
		);
		if(!$id){
			return;
		}
		$post = get_post($id);
		if($post){
			$post_custom = get_post_custom($post->ID);
			$post_custom = $this->helper->clean_meta($post_custom);
			$defaults = $this->helper->default_options();
			$post_custom = codenegar_parse_args($post_custom, $defaults); // merging with default options
			if($post->post_status != 'publish'){ // slider is draft or something
				return;
			}
			
			$this->html->add_css($post->ID, $post_custom);
			return $this->html->get_html($post->ID, $post_custom);
		}
		return; // If post is invalid return nothing
	}

	function activate() {
		
	}
	
	function plugins_loaded(){
		load_plugin_textdomain( $this->text_domain, false, $this->path . 'languages/');
	}
	
	function add_post_type() {
	
		// Labels
		$labels = array(
				'name'          => __('Roundabout', $this->text_domain),
				'singular_name' => __('Slider', $this->text_domain),
				'add_new'       => __('Add Slider', $this->text_domain),
				'all_items'     => __('All Sliders', $this->text_domain),
				'add_new_item'  => __('Add Slider', $this->text_domain),
				'edit_item'     => __('Edit Slider', $this->text_domain),
				'new_item'      => __('New Slider', $this->text_domain),
				'view_item'     => __('View Slider', $this->text_domain),
				'search_items'  => __('Search Sliders', $this->text_domain),
				'not_found'     => __('No Sliders Found', $this->text_domain)
		);
		
		// Settings
		$settings = array(
				'labels'               => $labels,
				'description'          => __('Roundabout Responsive Slider', $this->text_domain),
				'public'               => true,
				'show_ui'              => true,
				'menu_icon'            => $this->url .'images/slider.png',
				'show_in_menu'         => true,
				'capability_type'      => 'post',
				'has_archive'          => false,
				'hierarchical'         => false,
				'exclude_from_search'  => true,
				'publicly_queryable'   => true,
				'show_in_nav_menus'    => false,
				'show_in_admin_bar'    => false,
				'can_export'    	   => true,
				'supports'             => array('title')
		);
		
		// Register the actual post type
		register_post_type('roundabout_slider', $settings);
	}

	function shortcode_column($columns) {
		$columns['codenegar_rcs_shortcode'] = __('Shortcode', $this->text_domain);
		return $columns;
	}
	
	public function register_frontend_assets(){
		// Add frontend assets in footer
		wp_register_style('codenegar-rcs-style', $this->url . 'css/style.css');
		wp_register_script('codenegar-tooltip-easing',  $this->url . 'js/easing.js', array('jquery'), false, true); // use tooltip slug to be compatible with my other plugin
		wp_register_script('codenegar-rcs-roundabout',  $this->url . 'js/roundabout.js', array(), false, true);
		wp_register_script('codenegar-rcs-shapes',  $this->url . 'js/shapes.js', array(), false, true);
		wp_register_script('codenegar-rcs-drag',  $this->url . 'js/drag.js', array(), false, true);
		wp_register_script('codenegar-rcs-drop',  $this->url . 'js/drop.js', array(), false, true);
		wp_register_script('codenegar-rcs-custom',  $this->url . 'js/script.js', array(), false, true);
	}
	
	public function load_frontend_assets(){
		
	}
	
	function shortcode_column_value($name) {
		global $post;
		switch ($name) {
			case 'codenegar_rcs_shortcode':
				$shortcode = '[roundabout_slider id="' . $post->ID . '" title="' . esc_attr($post->post_title) . '"]';
				echo $shortcode;
		}
	}
}

// Initalize CodeNegar content tooltip Global Object
$codeNegar_rcs = new CodeNegar_rcs();

// Add an activation hook
register_activation_hook(__FILE__, array(&$codeNegar_rcs, 'activate'));

// Run the plugins initialization method
add_action('init', array(&$codeNegar_rcs, 'initialize'));
add_filter('manage_edit-roundabout_slider_columns', array(&$codeNegar_rcs,'shortcode_column'));
add_action('manage_posts_custom_column',  array(&$codeNegar_rcs,'shortcode_column_value'));
add_action('plugins_loaded', array(&$codeNegar_rcs,'plugins_loaded'));

// Register frontend/admin scripts and styles
add_action('wp_enqueue_scripts', array(&$codeNegar_rcs, 'register_frontend_assets'));

// Load frontend scripts and styles
add_action('wp_enqueue_scripts', array(&$codeNegar_rcs, 'load_frontend_assets'));

//  Add filter to ensure the tooltip is displayed when user updates a tooltip
add_filter('post_updated_messages',  array(&$codeNegar_rcs->helper, 'post_update_messages'));

// Remove extra tooltip list links
add_filter( 'post_row_actions', array(&$codeNegar_rcs->helper, 'remove_row_actions'), 10, 1 );

// Save global current post meta boxes order
add_action( 'wp_ajax_meta-box-order', array(&$codeNegar_rcs->helper, 'save_meta_box_order'), 1);
?>